<!--- Hugo front matter used to generate the website version of this page:
linkTitle: Events
--->

# Semantic conventions for Azure resource log events

**Status**: [Development][DocumentStatus]

This document defines semantic conventions for instrumentations that emit Azure
Resource Log events.

## Azure Resource Log

<!-- semconv event.az.resource.log -->
<!-- NOTE: THIS TEXT IS AUTOGENERATED. DO NOT EDIT BY HAND. -->
<!-- see templates/registry/markdown/snippet.md.j2 -->
<!-- prettier-ignore-start -->
<!-- markdownlint-capture -->
<!-- markdownlint-disable -->

**Status:** ![Development](https://img.shields.io/badge/-development-blue)

The event name MUST be `az.resource.log`.

Describes Azure Resource Log event, see [Azure Resource Log Top-level Schema](https://learn.microsoft.com/azure/azure-monitor/essentials/resource-logs-schema#top-level-common-schema) for more details.

| Attribute  | Type | Description  | Examples  | [Requirement Level](https://opentelemetry.io/docs/specs/semconv/general/attribute-requirement-level/) | Stability |
|---|---|---|---|---|---|
| [`az.service_request_id`](/docs/attributes-registry/azure.md) | string | The unique identifier of the service request. It's generated by the Azure service and returned with the response. | `00000000-0000-0000-0000-000000000000` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| [`cloud.resource_id`](/docs/attributes-registry/cloud.md) | string | The [Fully Qualified Azure Resource ID](https://docs.microsoft.com/rest/api/resources/resources/get-by-id) the log is emitted for. | `arn:aws:lambda:REGION:ACCOUNT_ID:function:my-function`; `//run.googleapis.com/projects/PROJECT_ID/locations/LOCATION_ID/services/SERVICE_ID`; `/subscriptions/<SUBSCRIPTION_GUID>/resourceGroups/<RG>/providers/Microsoft.Web/sites/<FUNCAPP>/functions/<FUNC>` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |

**Body fields:**

:warning: Body fields will be moved to complex attributes once the
semantic convention tooling supports complex attributes
(see [#1870](https://github.com/open-telemetry/semantic-conventions/issues/1870)).

| Body Field  | Type | Description  | Examples  | [Requirement Level](https://opentelemetry.io/docs/specs/semconv/general/attribute-requirement-level/) | Stability |
|---|---|---|---|---|---|
| `category` | string | The Azure category of the log entry. | `AuditEvent`; `GatewayLogs`; `ApplicationGatewayAccessLog` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `correlation.id` | string | The correlation ID of the log entry. | `607964b6-41a5-4e24-a5db-db7aab3b9b34` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `duration` | int | The duration of the operations in milliseconds. | `1000` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `identity` | undefined | "A JSON blob that describes the identity of the user or application that performed the operation." [1] |  | `Opt-In` | ![Development](https://img.shields.io/badge/-development-blue) |
| `operation.name` | string | The name of the operation. | `SecretGet`; `Microsoft.ApiManagement/GatewayLogs`; `ApplicationGatewayAccess` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `operation.version` | string | The version of the operation. | `1.0` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `properties` | undefined | The properties provided in the Azure Resource Log. |  | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `result.description` | string | The description of the result. | `The operation was successful`; `The operation failed` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `result.signature` | string | The substatus of associated with the logged event. | `OK` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `result.type` | string | The status associated with the logged event. | `Succeeded`; `Failed`; `Started` | `Recommended` | ![Development](https://img.shields.io/badge/-development-blue) |
| `tenant.id` | string | The tenant ID of the Active Directory tenant that this event is tied to. | `00000000-0000-0000-0000-000000000000` | `Conditionally Required` [2] | ![Development](https://img.shields.io/badge/-development-blue) |

**[1]:** Typically, this field includes the authorization and claims or JWT token from Active Directory.

> [!Warning]
> This field contains sensitive (PII) information.

**[2] `tenant.id`:** if the event is tied to an Active Directory tenant.

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->
<!-- END AUTOGENERATED TEXT -->
<!-- endsemconv -->

[DocumentStatus]: https://opentelemetry.io/docs/specs/otel/document-status
